==> gdis_0.81.orig.tar.gz: gdis-0.81/gtkshorts.h <==

/* fill types for box packing */
enum {FF, TF, FT, TT, LB};

/* generation 2 shortcuts */
void gtksh_relation_update(struct model_pak *);


GtkWidget *gtksh_icon_button(const gchar *, const gchar *,
                             gpointer, gpointer,
                             GtkWidget *);
GtkWidget *gtksh_stock_button(const gchar *,
                              gpointer, gpointer,
                              GtkWidget *);

/* TODO - make auto_check use same protoype as direct_check */
GtkWidget *gtksh_auto_check(gchar *, gpointer , gpointer , gint *, GtkWidget *);
GtkWidget *gtksh_direct_check(gchar *, gint *, gpointer , gpointer , GtkWidget *);

/* my shortcut routines for gtk interface construction */
GtkWidget *new_csd(gchar *, gpointer);
GtkWidget *new_check_button(gchar *, gpointer, gpointer, gint, GtkWidget *);

GtkWidget *gtksh_button(gchar *, gpointer, gpointer, GtkWidget *, gint);
GtkWidget *gtksh_button_x(gchar *, gpointer, gpointer, GtkWidget *);

void gtksh_button_label(gchar *, gchar *, gpointer, gpointer, GtkWidget *);

void new_radio_group(gint, GtkWidget *, gint);
GtkWidget *add_radio_button(gchar *, gpointer, gpointer);

GtkWidget *new_spinner(gchar *, gdouble, gdouble, gdouble,
                       gpointer, gpointer, GtkWidget *);

GtkWidget *gtksh_auto_spin(gchar *, gdouble *, gdouble, gdouble, gdouble,
                           gpointer, gpointer, GtkWidget *);
GtkWidget *gtksh_direct_spin(gchar *, gdouble *, gdouble, gdouble, gdouble,
                             gpointer, gpointer, GtkWidget *);

GtkWidget *gtksh_new_spin(gchar *, gdouble, gdouble, gdouble,
                          gpointer, GtkWidget *);

GtkWidget *gtksh_direct_hscale(gdouble, gdouble, gdouble,
                               gpointer, gpointer, gpointer, GtkWidget *);

==> gdis_0.86.orig.tar.gz: gdis-0.86/gtkshorts.h <==

/* fill types for box packing */
enum {FF, TF, FT, TT, LB};

/* generation 2 shortcuts */
void gtksh_relation_update(struct model_pak *);


GtkWidget *gtksh_icon_button(const gchar *, const gchar *,
                             gpointer, gpointer,
                             GtkWidget *);
GtkWidget *gtksh_stock_button(const gchar *,
                              gpointer, gpointer,
                              GtkWidget *);

/* TODO - make auto_check use same protoype as direct_check */
GtkWidget *gtksh_auto_check(gchar *, gpointer , gpointer , gint *, GtkWidget *);
GtkWidget *gtksh_direct_check(gchar *, gint *, gpointer , gpointer , GtkWidget *);

/* my shortcut routines for gtk interface construction */
GtkWidget *new_csd(gchar *, gpointer);
GtkWidget *new_check_button(gchar *, gpointer, gpointer, gint, GtkWidget *);

GtkWidget *gtksh_button(gchar *, gpointer, gpointer, GtkWidget *, gint);
GtkWidget *gtksh_button_x(gchar *, gpointer, gpointer, GtkWidget *);

void gtksh_button_label(gchar *, gchar *, gpointer, gpointer, GtkWidget *);

void new_radio_group(gint, GtkWidget *, gint);
GtkWidget *add_radio_button(gchar *, gpointer, gpointer);

GtkWidget *new_spinner(gchar *, gdouble, gdouble, gdouble,
                       gpointer, gpointer, GtkWidget *);

GtkWidget *gtksh_auto_spin(gchar *, gdouble *, gdouble, gdouble, gdouble,
                           gpointer, gpointer, GtkWidget *);
GtkWidget *gtksh_direct_spin(gchar *, gdouble *, gdouble, gdouble, gdouble,
                             gpointer, gpointer, GtkWidget *);

GtkWidget *gtksh_new_spin(gchar *, gdouble, gdouble, gdouble,
                          gpointer, GtkWidget *);

GtkWidget *gtksh_direct_hscale(gdouble, gdouble, gdouble,
                               gpointer, gpointer, gpointer, GtkWidget *);

GtkWidget *gtksh_auto_text_label(gchar **);
GtkWidget *gtksh_auto_int_label(gint *);
GtkWidget *gtksh_auto_float_label(gdouble *);
